@@ -15,7 +15,6 @@
 #include <span>
 #include <string>
 #include <string_view>
-#include <unordered_map>
 #include <vector>
 
 namespace Botan {
@@ -26,7 +25,7 @@ class DER_Encoder;
 /**
 * ASN.1 Class Tags
 */
-enum class ASN1_Class : uint32_t {
+enum class ASN1_Class : uint32_t /* NOLINT(performance-enum-size) */ {
    Universal = 0b0000'0000,
    Application = 0b0100'0000,
    ContextSpecific = 0b1000'0000,
@@ -41,7 +40,7 @@ enum class ASN1_Class : uint32_t {
 /**
 * ASN.1 Type Tags
 */
-enum class ASN1_Type : uint32_t {
+enum class ASN1_Type : uint32_t /* NOLINT(performance-enum-size) */ {
    Eoc = 0x00,
    Boolean = 0x01,
    Integer = 0x02,
@@ -69,7 +68,7 @@ enum class ASN1_Type : uint32_t {
 };
 
 inline bool intersects(ASN1_Class x, ASN1_Class y) {
-   return static_cast<uint32_t>(x) & static_cast<uint32_t>(y);
+   return (static_cast<uint32_t>(x) & static_cast<uint32_t>(y)) != 0;
 }
 
 inline ASN1_Type operator|(ASN1_Type x, ASN1_Type y) {
@@ -118,6 +117,8 @@ class BOTAN_PUBLIC_API(2, 0) ASN1_Object {
       ASN1_Object() = default;
       ASN1_Object(const ASN1_Object&) = default;
       ASN1_Object& operator=(const ASN1_Object&) = default;
+      ASN1_Object(ASN1_Object&&) = default;
+      ASN1_Object& operator=(ASN1_Object&&) = default;
       virtual ~ASN1_Object() = default;
 };
 
@@ -126,15 +127,13 @@ class BOTAN_PUBLIC_API(2, 0) ASN1_Object {
 */
 class BOTAN_PUBLIC_API(2, 0) BER_Object final {
    public:
-      BER_Object() : m_type_tag(ASN1_Type::NoObject), m_class_tag(ASN1_Class::Universal) {}
+      BER_Object() = default;
 
       BER_Object(const BER_Object& other) = default;
-
-      BER_Object& operator=(const BER_Object& other) = default;
-
       BER_Object(BER_Object&& other) = default;
-
+      BER_Object& operator=(const BER_Object& other) = default;
       BER_Object& operator=(BER_Object&& other) = default;
+      ~BER_Object() = default;
 
       bool is_set() const { return m_type_tag != ASN1_Type::NoObject; }
 
@@ -161,8 +160,8 @@ class BOTAN_PUBLIC_API(2, 0) BER_Object final {
       bool is_a(int type_tag, ASN1_Class class_tag) const;
 
    private:
-      ASN1_Type m_type_tag;
-      ASN1_Class m_class_tag;
+      ASN1_Type m_type_tag = ASN1_Type::NoObject;
+      ASN1_Class m_class_tag = ASN1_Class::Universal;
       secure_vector<uint8_t> m_value;
 
       friend class BER_Decoder;
@@ -199,7 +198,7 @@ bool maybe_BER(DataSource& src);
 */
 class BOTAN_PUBLIC_API(2, 0) BER_Decoding_Error : public Decoding_Error {
    public:
-      explicit BER_Decoding_Error(std::string_view);
+      explicit BER_Decoding_Error(std::string_view err);
 };
 
 /**
@@ -231,7 +230,7 @@ class BOTAN_PUBLIC_API(2, 0) OID final : public ASN1_Object {
       /**
       * Initialize an OID from a sequence of integer values
       */
-      explicit OID(std::initializer_list<uint32_t> init);
+      OID(std::initializer_list<uint32_t> init);
 
       /**
       * Initialize an OID from a vector of integer values
@@ -256,8 +255,8 @@ class BOTAN_PUBLIC_API(2, 0) OID final : public ASN1_Object {
       */
       static void register_oid(const OID& oid, std::string_view name);
 
-      void encode_into(DER_Encoder&) const override;
-      void decode_from(BER_Decoder&) override;
+      void encode_into(DER_Encoder& to) const override;
+      void decode_from(BER_Decoder& from) override;
 
       /**
       * Find out whether this OID is empty
@@ -304,10 +303,15 @@ class BOTAN_PUBLIC_API(2, 0) OID final : public ASN1_Object {
       /**
       * Return a hash code for this OID
       *
-      * This value is only meant as a std::unsorted_map hash and
+      * This value is only meant as a std::unordered_map hash and
       * can change value from release to release.
       */
-      size_t hash_code() const;
+      uint64_t hash_code() const;
+
+      /**
+      * Check if this OID matches the provided value
+      */
+      bool matches(std::initializer_list<uint32_t> other) const;
 
       /**
       * Get this OID as list (vector) of its components.
@@ -356,10 +360,10 @@ BOTAN_PUBLIC_API(2, 0) bool operator<(const OID& a, const OID& b);
 class BOTAN_PUBLIC_API(2, 0) ASN1_Time final : public ASN1_Object {
    public:
       /// DER encode a ASN1_Time
-      void encode_into(DER_Encoder&) const override;
+      void encode_into(DER_Encoder& to) const override;
 
       // Decode a BER encoded ASN1_Time
-      void decode_from(BER_Decoder&) override;
+      void decode_from(BER_Decoder& from) override;
 
       /// Return an internal string representation of the time
       std::string to_string() const;
@@ -379,8 +383,11 @@ class BOTAN_PUBLIC_API(2, 0) ASN1_Time final : public ASN1_Object {
       /// Create a ASN1_Time from a time point
       explicit ASN1_Time(const std::chrono::system_clock::time_point& time);
 
+      /// Create an ASN1_Time from seconds since epoch
+      static ASN1_Time from_seconds_since_epoch(uint64_t seconds);
+
       /// Create an ASN1_Time from string
-      ASN1_Time(std::string_view t_spec);
+      BOTAN_FUTURE_EXPLICIT ASN1_Time(std::string_view t_spec);
 
       /// Create an ASN1_Time from string and a specified tagging (Utc or Generalized)
       ASN1_Time(std::string_view t_spec, ASN1_Type tag);
@@ -407,12 +414,12 @@ class BOTAN_PUBLIC_API(2, 0) ASN1_Time final : public ASN1_Object {
 /*
 * Comparison Operations
 */
-BOTAN_PUBLIC_API(2, 0) bool operator==(const ASN1_Time&, const ASN1_Time&);
-BOTAN_PUBLIC_API(2, 0) bool operator!=(const ASN1_Time&, const ASN1_Time&);
-BOTAN_PUBLIC_API(2, 0) bool operator<=(const ASN1_Time&, const ASN1_Time&);
-BOTAN_PUBLIC_API(2, 0) bool operator>=(const ASN1_Time&, const ASN1_Time&);
-BOTAN_PUBLIC_API(2, 0) bool operator<(const ASN1_Time&, const ASN1_Time&);
-BOTAN_PUBLIC_API(2, 0) bool operator>(const ASN1_Time&, const ASN1_Time&);
+BOTAN_PUBLIC_API(2, 0) bool operator==(const ASN1_Time& x, const ASN1_Time& y);
+BOTAN_PUBLIC_API(2, 0) bool operator!=(const ASN1_Time& x, const ASN1_Time& y);
+BOTAN_PUBLIC_API(2, 0) bool operator<=(const ASN1_Time& x, const ASN1_Time& y);
+BOTAN_PUBLIC_API(2, 0) bool operator>=(const ASN1_Time& x, const ASN1_Time& y);
+BOTAN_PUBLIC_API(2, 0) bool operator<(const ASN1_Time& x, const ASN1_Time& y);
+BOTAN_PUBLIC_API(2, 0) bool operator>(const ASN1_Time& x, const ASN1_Time& y);
 
 typedef ASN1_Time X509_Time;
 
@@ -422,8 +429,8 @@ typedef ASN1_Time X509_Time;
 */
 class BOTAN_PUBLIC_API(2, 0) ASN1_String final : public ASN1_Object {
    public:
-      void encode_into(DER_Encoder&) const override;
-      void decode_from(BER_Decoder&) override;
+      void encode_into(DER_Encoder& to) const override;
+      void decode_from(BER_Decoder& from) override;
 
       ASN1_Type tagging() const { return m_tag; }
 
@@ -456,10 +463,10 @@ class BOTAN_PUBLIC_API(2, 0) ASN1_String final : public ASN1_Object {
 */
 class BOTAN_PUBLIC_API(2, 0) AlgorithmIdentifier final : public ASN1_Object {
    public:
-      enum Encoding_Option { USE_NULL_PARAM, USE_EMPTY_PARAM };
+      enum Encoding_Option : uint8_t { USE_NULL_PARAM, USE_EMPTY_PARAM }; /* NOLINT(*-use-enum-class) */
 
-      void encode_into(DER_Encoder&) const override;
-      void decode_from(BER_Decoder&) override;
+      void encode_into(DER_Encoder& to) const override;
+      void decode_from(BER_Decoder& from) override;
 
       AlgorithmIdentifier() = default;
 
@@ -495,15 +502,15 @@ class BOTAN_PUBLIC_API(2, 0) AlgorithmIdentifier final : public ASN1_Object {
 /*
 * Comparison Operations
 */
-BOTAN_PUBLIC_API(2, 0) bool operator==(const AlgorithmIdentifier&, const AlgorithmIdentifier&);
-BOTAN_PUBLIC_API(2, 0) bool operator!=(const AlgorithmIdentifier&, const AlgorithmIdentifier&);
+BOTAN_PUBLIC_API(2, 0) bool operator==(const AlgorithmIdentifier& x, const AlgorithmIdentifier& y);
+BOTAN_PUBLIC_API(2, 0) bool operator!=(const AlgorithmIdentifier& x, const AlgorithmIdentifier& y);
 
 }  // namespace Botan
 
 template <>
 class std::hash<Botan::OID> {
    public:
-      size_t operator()(const Botan::OID& oid) const noexcept { return oid.hash_code(); }
+      size_t operator()(const Botan::OID& oid) const noexcept { return static_cast<size_t>(oid.hash_code()); }
 };
 
 #endif
