@@ -62,7 +62,7 @@ class BOTAN_PUBLIC_API(2, 0) BlockCipher : public SymmetricAlgorithm {
       virtual size_t parallelism() const { return 1; }
 
       /**
-      * @return prefererred parallelism of this cipher in bytes
+      * @return preferred parallelism of this cipher in bytes
       */
       size_t parallel_bytes() const { return parallelism() * block_size() * BlockCipher::ParallelismMult; }
 
@@ -83,7 +83,7 @@ class BOTAN_PUBLIC_API(2, 0) BlockCipher : public SymmetricAlgorithm {
 
       /**
       * Decrypt a block.
-      * @param in The ciphertext block to be decypted as a byte array.
+      * @param in The ciphertext block to be decrypted as a byte array.
       * Must be of length block_size().
       * @param out The byte array designated to hold the decrypted block.
       * Must be of length block_size().
@@ -209,7 +209,7 @@ class BOTAN_PUBLIC_API(2, 8) Tweakable_Block_Cipher : public BlockCipher {
 template <size_t BS, size_t KMIN, size_t KMAX = 0, size_t KMOD = 1, typename BaseClass = BlockCipher>
 class Block_Cipher_Fixed_Params : public BaseClass {
    public:
-      enum { BLOCK_SIZE = BS }; /* NOLINT(*-enum-size) */
+      enum { BLOCK_SIZE = BS }; /* NOLINT(*-enum-size,*-use-enum-class) */
 
       size_t block_size() const final { return BS; }
 
