@@ -3,7 +3,7 @@
 
 /**
 * @file  build.h
-* @brief Build configuration for Botan 3.9.0
+* @brief Build configuration for Botan 3.10.0
 */
 
 /* NOLINTBEGIN(*-macro-usage,*-macro-to-enum) */
@@ -26,7 +26,7 @@
 /**
 * The minor version of the release
 */
-#define BOTAN_VERSION_MINOR 9
+#define BOTAN_VERSION_MINOR 10
 
 /**
 * The patch version of the release
@@ -42,7 +42,7 @@
  *
  * TODO(Botan4) remove this
  */
-#define BOTAN_VERSION_DATESTAMP 20250805
+#define BOTAN_VERSION_DATESTAMP 20251106
 
 /**
  * A string set to the release type
@@ -62,7 +62,7 @@
  *
  * TODO(Botan4) remove this
  */
-#define BOTAN_VERSION_VC_REVISION "git:07e1cfe0a06b224bbb37ad534736924931184246"
+#define BOTAN_VERSION_VC_REVISION "git:e27d332089247f04e89854a2e60a3af2ec4e430f"
 
 /**
  * A macro expanding to a string that is set at build time using the
@@ -74,7 +74,7 @@
  *
  * TODO(Botan4) remove this
  */
-#define BOTAN_DISTRIBUTION_INFO "unspecified"
+#define BOTAN_DISTRIBUTION_INFO "KaOS"
 
 /**
  * @}
@@ -126,6 +126,9 @@
 #define BOTAN_HAS_ARGON2 20210407
 #define BOTAN_HAS_ARGON2_FMT 20210407
 #define BOTAN_HAS_ARIA 20170415
+#define BOTAN_HAS_ASCON_AEAD128 20250823
+#define BOTAN_HAS_ASCON_HASH256 20250816
+#define BOTAN_HAS_ASCON_XOF128 20250817
 #define BOTAN_HAS_ASN1 20201106
 #define BOTAN_HAS_AUTO_RNG 20161126
 #define BOTAN_HAS_AUTO_SEEDING_RNG 20160821
@@ -196,7 +199,7 @@
 #define BOTAN_HAS_EMSA_RAW 20131128
 #define BOTAN_HAS_EMSA_X931 20140118
 #define BOTAN_HAS_ENTROPY_SOURCE 20151120
-#define BOTAN_HAS_FFI 20250506
+#define BOTAN_HAS_FFI 20250829
 #define BOTAN_HAS_FILTERS 20160415
 #define BOTAN_HAS_FPE_FE1 20131128
 #define BOTAN_HAS_FRODOKEM 20230801
@@ -263,7 +266,6 @@
 #define BOTAN_HAS_PKCS5_PBES2 20141119
 #define BOTAN_HAS_PKCSV15_ENCRYPTION_PADDING 20250126
 #define BOTAN_HAS_PKCSV15_SIGNATURE_PADDING 20250126
-#define BOTAN_HAS_PK_PADDING 20131128
 #define BOTAN_HAS_POLY1305 20141227
 #define BOTAN_HAS_PROCESSOR_RNG 20200508
 #define BOTAN_HAS_PSK_DB 20171119
@@ -276,6 +278,7 @@
 #define BOTAN_HAS_RIPEMD_160 20131128
 #define BOTAN_HAS_ROUGHTIME 20190220
 #define BOTAN_HAS_RSA 20160730
+#define BOTAN_HAS_RSA_ENCRYPTION_PADDING 20250720
 #define BOTAN_HAS_RSA_SIGNATURE_PADDING 20250720
 #define BOTAN_HAS_SALSA20 20171114
 #define BOTAN_HAS_SCRYPT 20180902
@@ -321,7 +324,6 @@
 #define BOTAN_HAS_TLS_12 20210608
 #define BOTAN_HAS_TLS_13 20241208
 #define BOTAN_HAS_TLS_13_PQC 20241208
-#define BOTAN_HAS_TLS_ASIO_STREAM 20181218
 #define BOTAN_HAS_TLS_CBC 20161008
 #define BOTAN_HAS_TLS_SESSION_MANAGER_SQL_DB 20141219
 #define BOTAN_HAS_TLS_SQLITE3_SESSION_MANAGER 20131128
@@ -358,7 +360,6 @@
 #define BOTAN_HAS_ARGON2_SSSE3 20220303
 #define BOTAN_HAS_BIGINT_MP 20151225
 #define BOTAN_HAS_BITVECTOR 20241202
-#define BOTAN_HAS_BOOST_ASIO 20131228
 #define BOTAN_HAS_CAMELLIA_GFNI 20250502
 #define BOTAN_HAS_CHACHA_AVX2 20180418
 #define BOTAN_HAS_CHACHA_AVX512 20230101
